From 4821dbf8c7ed4303320430e8b803bee60965ae5a Mon Sep 17 00:00:00 2001
From: q66 <daniel@octaforge.org>
Date: Sun, 30 Jun 2019 18:14:58 +0200
Subject: [PATCH] libtool: patch the libtool script for native envs when cross

When libtool is cross compiled, it introduces assumptions about
the cross toolchain into the resulting /usr/bin/libtool script,
which prevents the script from working when used on the target
machine in a "native" environment.

The reason for this is primarily that the "short triplet" versions
of the binutils tools do not exist in the target system, only in
the crosstoolchain. Even if they did though, this would still be
wrong.

This impacts some real packages, for example libtommath does not
build when built natively in an environment for which libtool was
cross compiled.
---
 srcpkgs/libtool/template | 24 +++++++++++++++++++++++-
 1 file changed, 23 insertions(+), 1 deletion(-)

diff --git a/srcpkgs/libtool/template b/srcpkgs/libtool/template
index 4d7687ab7a7..d0746e15b4b 100644
--- a/srcpkgs/libtool/template
+++ b/srcpkgs/libtool/template
@@ -1,7 +1,7 @@
 # Template build file for 'libtool'
 pkgname=libtool
 version=2.4.6
-revision=2
+revision=3
 hostmakedepends="perl automake help2man"
 depends="tar sed"
 build_style=gnu-configure
@@ -17,6 +17,28 @@ pre_configure() {
 	./bootstrap --force
 }
 
+post_install() {
+	# this is necessary, because when cross building, libtool will pick up
+	# the binary names of the crosstoolchain, which are prefixed with the
+	# short triplet (i.e. arch-linux-env instead of arch-unknown-linux-env)
+	# and those are not present in a real native environment; also the
+	# sysroot var will be set and cflags will include extra cross-related
+	# things that need to go; the target libtool script is meant to be used
+	# in native environments, not in cross environments, so patch the script
+	if [ "$CROSS_BUILD" ]; then
+		# e.g. AR="armv7l-linux-gnueabihf-ar" becomes AR="ar"
+		vsed -i -e "s,=\"${XBPS_CROSS_TRIPLET}\-,=\",g" \
+		 ${PKGDESTDIR}/usr/bin/libtool
+
+		# clear out any sysroot present
+		vsed -i -e "s,^lt_sysroot=.*,lt_sysroot=," \
+		 ${PKGDESTDIR}/usr/bin/libtool
+
+		# clear out sysroot include path
+		vsed -i -e "s,\-I${XBPS_CROSS_BASE}/usr/include,,g" \
+		 ${PKGDESTDIR}/usr/bin/libtool
+	fi
+}
 
 libltdl-devel_package() {
 	depends="libltdl-${version}_${revision}"
